

* Version 0.0.18:
    - Support for Python 3.8
* Version 0.1.0
    - Stable version for Python 3.7 and 3.8
    - Addition of sqlparse and IPython to requirements.txt
    - Addition of ``scriptparser.render_sql()`` for rendering sql in IPython/Jupyter environments


